Index: branches/1.3/lang/python/Rappture/PyRpLibrary.cc
===================================================================
--- branches/1.3/lang/python/Rappture/PyRpLibrary.cc	(revision 5556)
+++ branches/1.3/lang/python/Rappture/PyRpLibrary.cc	(revision 5557)
@@ -48,5 +48,5 @@
 
 
-static int 
+static int
 getArgCount(PyObject *args, PyObject *keywds, int *argc)
 {
@@ -129,5 +129,5 @@
 
 static int
-PyObjectToBoolean(PyObject *objPtr, const char *defValue, const char *argName, 
+PyObjectToBoolean(PyObject *objPtr, const char *defValue, const char *argName,
 		  int *resultPtr)
 {
@@ -147,5 +147,5 @@
 	value = PyObject_IsTrue(objPtr);
 	if (value < 0) {
-             PyErr_Format(PyExc_ValueError, 
+             PyErr_Format(PyExc_ValueError,
 		"PyObjectToBoolean: bad boolean object");
 	    return RP_ERROR;
@@ -168,5 +168,5 @@
     } else if (PyString_Check(objPtr)) {
 	const char *string;
-	
+
         string = PyString_AsString(objPtr);
         if (string == NULL) {
@@ -370,5 +370,5 @@
 
 PyDoc_STRVAR(ElementProcDoc,
-"element ([path=\'\'][, as=\'object\']) -> returns string or Rappture Library Object\n\
+"element ([path=\'\'][, type=\'object\']) -> returns string or Rappture Library Object\n\
 \n\
 Clients use this to query a particular element within the \n\
@@ -381,5 +381,5 @@
 By default, this method returns an object representing the \n\
 DOM node referenced by the path.  This is changed by setting \n\
-the \"as\" argument to \"id\" (for name of the tail element), \n\
+the \"type\" argument to \"id\" (for name of the tail element), \n\
 to \"type\" (for the type of the tail element), to \"component\" \n\
 (for the component name \"type(id)\"), or to \"object\" \n\
@@ -391,5 +391,5 @@
 {
     char* path = (char *)"";
-    char* as = (char *)"object";
+    char* type = (char *)"object";
     RpLibrary* retlib = NULL;
     PyObject* retVal = NULL;
@@ -398,5 +398,5 @@
     static char *kwlist[] = {
         (char *)"path",
-        (char *)"as",
+        (char *)"type",
         NULL
     };
@@ -422,8 +422,8 @@
 
     if (!PyArg_ParseTupleAndKeywords(args, keywds, "|ss",
-                kwlist, &path, &as)) {
+                kwlist, &path, &type)) {
         /* incorrect input values */
         // tested with ElementTests.testArguments_ArgsWrongType2()
-        PyErr_Format(PyExc_TypeError,"element ([path=\'\'][, as=\'object\'])");
+        PyErr_Format(PyExc_TypeError,"element ([path=\'\'][, type=\'object\'])");
         return retVal;
     }
@@ -432,23 +432,23 @@
 
     if (retlib != NULL) {
-        if ((as == NULL) || ((*as == 'o') && (strcmp("object",as) == 0)) ) {
+        if ((type == NULL) || ((*type == 'o') && (strcmp("object",type) == 0)) ) {
             // tested with ElementTests.testArguments_PathArg()
             retVal = RpLibraryObject_FromLibrary(retlib);
-        } else if ((*as == 'c') && (strcmp("component",as) == 0)) {
+        } else if ((*type == 'c') && (strcmp("component",type) == 0)) {
             // tested with ElementTests.testArguments_TwoArgs()
             retVal = PyString_FromString(retlib->nodeComp().c_str());
-        } else if ((*as == 'i') && (strcmp("id",as) == 0)) {
-            // tested with ElementTests.testArguments_AsId()
+        } else if ((*type == 'i') && (strcmp("id",type) == 0)) {
+            // tested with ElementTests.testArguments_typeId()
             retVal = PyString_FromString(retlib->nodeId().c_str());
-        } else if ((*as == 't') && (strcmp("type",as) == 0)) {
-            // tested with ElementTests.testArguments_AsKeywordArgs()
+        } else if ((*type == 't') && (strcmp("type",type) == 0)) {
+            // tested with ElementTests.testArguments_typeKeywordArgs()
             retVal = PyString_FromString(retlib->nodeType().c_str());
-        } else if ((*as == 'p') && (strcmp("path",as) == 0)) {
+        } else if ((*type == 'p') && (strcmp("path",type) == 0)) {
             // tested with ElementTests.testArguments_TwoKeywordArgs()
             retVal = PyString_FromString(retlib->nodePath().c_str());
         } else {
-            // tested with ElementTests.testArguments_UnrecognizedAs()
+            // tested with ElementTests.testArguments_Unrecognizedtype()
             PyErr_Format(PyExc_ValueError,
-                "element() \'as\' arg must be \'object\' or \'component\' or \'id\' or \'type\' or \'path\'");
+                "element() \'type\' arg must be \'object\' or \'component\' or \'id\' or \'type\' or \'path\'");
         }
     }
@@ -649,4 +649,5 @@
         NULL
     };
+
     appendFlag = compressFlag = FALSE;
     strObjPtr = appendObjPtr = valueObjPtr = compressObjPtr = NULL;
@@ -670,5 +671,5 @@
         return NULL;
     }
-    if (!PyArg_ParseTupleAndKeywords(args, keywds, "sO|sOsO", kwlist, &path, 
+    if (!PyArg_ParseTupleAndKeywords(args, keywds, "sO|sOsO", kwlist, &path,
 	&valueObjPtr, &id, &appendObjPtr, &type, &compressObjPtr)) {
         return NULL;
@@ -690,5 +691,5 @@
     strObjPtr = PyObject_Str(valueObjPtr);
     if (RpLibraryObject_IsValid(valueObjPtr)) {
-        self->lib->put( std::string(path), 
+        self->lib->put( std::string(path),
 		RpLibraryObject_AsLibrary(valueObjPtr), "", appendFlag);
     } else if (strObjPtr != NULL) {
@@ -704,5 +705,5 @@
                                 std::string(string), "", appendFlag);
             } else {
-                self->lib->putData( std::string(path), string, length, 
+                self->lib->putData( std::string(path), string, length,
 			appendFlag);
             }
@@ -755,5 +756,5 @@
 
     static char *kwlist[] = {
-	(char *)"status", 
+	(char *)"status",
 	NULL
     };
Index: branches/1.3/lang/python/Rappture/library.py
===================================================================
--- branches/1.3/lang/python/Rappture/library.py	(revision 5556)
+++ branches/1.3/lang/python/Rappture/library.py	(revision 5557)
@@ -43,5 +43,5 @@
 
     # ------------------------------------------------------------------
-    def element(self, path="", as="object"):
+    def element(self, path="", type="object"):
         """
         Clients use this to query a particular element within the
@@ -54,5 +54,5 @@
         By default, this method returns an object representing the
         DOM node referenced by the path.  This is changed by setting
-        the "as" argument to "id" (for name of the tail element),
+        the "type" argument to "id" (for name of the tail element),
         to "type" (for the type of the tail element), to "component"
         (for the component name "type(id)"), or to "object"
@@ -64,27 +64,27 @@
             return None
 
-        if as == 'object':
+        if type == 'object':
             return library(node)
-        elif as == 'component':
+        elif type == 'component':
             return self._node2comp(node)
-        elif as == 'id':
+        elif type == 'id':
             return self._node2name(node)
-        elif as == 'type':
+        elif type == 'type':
             return node.tagName
 
-        raise ValueError, "bad as value '%s': should be component, id, object, type" % as
-
-    # ------------------------------------------------------------------
-    def children(self, path="", as="object", type=None):
+        raise ValueError, "bad type value '%s': should be component, id, object, type" % type
+
+    # ------------------------------------------------------------------
+    def children(self, path="", type="object", rtype=None):
         """
         Clients use this to query the children of a particular element
         within the entire data structure.  This is just like the
         element() method, but it returns the children of the element
         instead of the element itself.  If the optional type argument
         is specified, then the return list is restricted to children
         of the specified type.
 
         By default, this method returns a list of objects representing
-        the children.  This is changed by setting the "as" argument
+        the children.  This is changed by setting the "type" argument
         to "id" (for tail names of all children), to "type" (for the
         types of all children), to "component" (for the path component
@@ -99,17 +99,17 @@
         nlist = [n for n in node.childNodes if not n.nodeName.startswith('#')]
 
-        if type:
-            nlist = [n for n in nlist if n.nodeName == type]
-
-        if as == 'object':
+        if rtype:
+            nlist = [n for n in nlist if n.nodeName == rtype]
+
+        if type == 'object':
             return [library(n) for n in nlist]
-        elif as == 'component':
+        elif type == 'component':
             return [self._node2comp(n) for n in nlist]
-        elif as == 'id':
+        elif type == 'id':
             return [self._node2name(n) for n in nlist]
-        elif as == 'type':
+        elif type == 'type':
             return [n.tagName for n in nlist]
 
-        raise ValueError, "bad as value '%s': should be component, id, object, type" % as
+        raise ValueError, "bad type value '%s': should be component, id, object, type" % type
 
     # ------------------------------------------------------------------
@@ -276,5 +276,5 @@
 
         If you include "#" instead of a specific number, a node
-        will be created automatically with a new number.  For example, 
+        will be created automatically with a new number.  For example,
         the path "foo.bar#" called the first time will create "foo.bar",
         the second time "foo.bar1", the third time "foo.bar2" and
@@ -64,27 +64,27 @@
         within the entire data structure.  This is just like the
         element() method, but it returns the children of the element
-        instead of the element itself.  If the optional type argument
+        instead of the element itself.  If the optional rtype argument
         is specified, then the return list is restricted to children
         of the specified type.
